import { Button } from '@material-ui/core'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import ActionModal from 'components/Action/ActionModal/ActionModal'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StarsContainer from 'components/CommonKit/StarsContainer/StarsContainer'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { Ecogesture, UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import ActionService from 'services/action.service'
import { useAppSelector } from 'store/hooks'
import { importIconById } from 'utils/utils'
import './actionBegin.scss'

interface ActionBeginProps {
  action?: Ecogesture
  setShowList: React.Dispatch<React.SetStateAction<boolean>>
  userChallenge: UserChallenge
}

const ActionBegin = ({
  action,
  setShowList,
  userChallenge,
}: ActionBeginProps) => {
  const { t } = useI18n()
  const client = useClient()
  const {
    global: { fluidTypes },
    profile: { isProfileTypeCompleted },
  } = useAppSelector(state => state.ecolyo)
  const [currentAction, setCurrentAction] = useState<Ecogesture>()
  const [actionIcon, setActionIcon] = useState<string>('')
  const [openLaunchModal, setOpenLaunchModal] = useState<boolean>(false)

  useEffect(() => {
    let subscribed = true
    const getAction = async () => {
      if (subscribed) {
        if (action) {
          setCurrentAction(action)
          const icon = await importIconById(action.id, 'ecogesture')
          setActionIcon(icon || defaultIcon)
        } else {
          const actionService = new ActionService(client)
          let actions: Ecogesture[] = []
          if (isProfileTypeCompleted) {
            actions = await actionService.getCustomActions(fluidTypes)
          } else {
            actions = await actionService.getDefaultActions()
          }

          setCurrentAction(actions[0])
          const icon = await importIconById(actions[0].id, 'ecogesture')
          setActionIcon(icon || defaultIcon)
        }
      }
    }
    getAction()
    return () => {
      subscribed = false
    }
  }, [action, client, fluidTypes, isProfileTypeCompleted])

  return (
    <div className="action-begin">
      {currentAction && (
        <div className="action-container">
          <div className="action-begin-container">
            <div className="icon-container">
              <StyledIcon
                className="action-icon"
                icon={actionIcon}
                size={100}
              />
            </div>
            <StarsContainer
              result={userChallenge.progress.actionProgress}
              isQuizBegin={true}
            />
            <h1 className="text-20-bold">{currentAction.shortName}</h1>
            <div className="action-duration text-18">
              {t('action.duration', {
                smartCount: currentAction.actionDuration,
              })}
            </div>
            <div className="action-text text-18-bold">
              {currentAction.actionName}
            </div>
            <div className="action-buttons">
              <Button
                onClick={() => setOpenLaunchModal(true)}
                className="btnSecondary"
              >
                {t('action.apply')}
              </Button>
              <Button
                onClick={() => setShowList(true)}
                className="btnSecondary"
              >
                {t('action.other')}
              </Button>
            </div>
          </div>
          <ActionModal
            open={openLaunchModal}
            action={currentAction}
            handleCloseClick={() => setOpenLaunchModal(false)}
            userChallenge={userChallenge}
          />
        </div>
      )}
    </div>
  )
}

export default ActionBegin
