import { Button } from '@material-ui/core'
import starFilled from 'assets/icons/visu/challenge/starFilled.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enums'
import { UserChallenge } from 'models'
import React, { useCallback } from 'react'
import { useNavigate } from 'react-router-dom'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { toggleChallengeActionNotification } from 'store/global/global.slice'
import { useAppDispatch } from 'store/hooks'
import './actionDone.scss'

const ActionDone = ({
  currentChallenge,
}: {
  currentChallenge: UserChallenge
}) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useAppDispatch()
  const navigate = useNavigate()
  const handleEndAction = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge = await challengeService.updateUserChallenge(
      currentChallenge,
      UserChallengeUpdateFlag.ACTION_DONE
    )
    dispatch(toggleChallengeActionNotification(false))
    dispatch(updateUserChallengeList(updatedChallenge))
    navigate(-1)
  }, [currentChallenge, dispatch, client, navigate])

  return (
    <div className="action-done-container">
      <div className="action-done">
        <div className="result-title"> {t('action.finished')}</div>
        <div>{t('action.resultText1')}</div>
        <div>{t('action.resultText2')}</div>
        <div>{t('action.resultText3')}</div>
        <div>{t('action.resultText4')}</div>
        <div className="stars">
          <span>5</span>
          <StyledIcon icon={starFilled} size={33} />
        </div>
        <Button className="btnSecondary" onClick={handleEndAction}>
          {t('action.ok')}
        </Button>
      </div>
    </div>
  )
}

export default ActionDone
