import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import chronoMini from 'assets/icons/visu/action/chrono-mini.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enums'
import { Ecogesture, UserChallenge } from 'models'
import React, { useCallback } from 'react'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { useAppDispatch } from 'store/hooks'
import './actionModal.scss'

interface ActionModalProps {
  open: boolean
  action: Ecogesture
  handleCloseClick: () => void
  userChallenge: UserChallenge
}

const ActionModal = ({
  open,
  action,
  handleCloseClick,
  userChallenge,
}: ActionModalProps) => {
  const client = useClient()
  const { t } = useI18n()
  const dispatch = useAppDispatch()
  const launchAction = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge = await challengeService.updateUserChallenge(
      userChallenge,
      UserChallengeUpdateFlag.ACTION_START,
      undefined,
      undefined,
      action
    )
    dispatch(updateUserChallengeList(updatedChallenge))
  }, [action, client, dispatch, userChallenge])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('action_modal.accessibility.window_title')}
      </div>
      <div className="action-modal">
        <StyledIcon icon={chronoMini} size={75} />
        <div className="action-title text-16-normal">
          {t('action.duration', {
            smartCount: action.actionDuration,
          })}
        </div>
        <div className="action-text text-16-normal">{action.longName}</div>
        <div className="buttons">
          <Button
            aria-label={t('action_modal.accessibility.button_accept')}
            className="btnSecondary"
            onClick={launchAction}
          >
            {t('action_modal.accept')}
          </Button>
          <Button
            aria-label={t('action_modal.accessibility.button_refuse')}
            className="btnSecondary"
            onClick={handleCloseClick}
          >
            {t('action_modal.refuse')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default ActionModal
