import { Button } from '@material-ui/core'
import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import classNames from 'classnames'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeSuccess, UserChallengeUpdateFlag } from 'enums'
import { UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import { useNavigate } from 'react-router-dom'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import {
  formatNumberValues,
  getChallengeTitleWithLineReturn,
  importIconById,
} from 'utils/utils'
import './challengeCardDone.scss'

const ChallengeCardDone = ({
  userChallenge,
}: {
  userChallenge: UserChallenge
}) => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const client = useClient()
  const dispatch = useAppDispatch()
  const { currentChallenge } = useAppSelector(state => state.ecolyo.challenge)
  const [winIcon, setWinIcon] = useState<string>(defaultIcon)
  const [lossIcon, setLossIcon] = useState<string>(defaultIcon)

  const getUserSaving = (_userChallenge: UserChallenge) => {
    let label
    if (_userChallenge.success === UserChallengeSuccess.WIN)
      label = t('challenge.card_done.saving')
    else label = t('challenge.card_done.depense')

    return label + ' '
  }

  const getResultLabel = (_userChallenge: UserChallenge) => {
    switch (_userChallenge.success) {
      case UserChallengeSuccess.WIN:
        return t('challenge.card_done.win')
      case UserChallengeSuccess.LOST:
      default:
        return t('challenge.card_done.lost')
    }
  }

  const getIcon = (_userChallenge: UserChallenge) => {
    if (_userChallenge.success == UserChallengeSuccess.WIN) return winIcon
    else return lossIcon
  }

  const goDuel = async () => {
    navigate('/challenges/duel?id=' + userChallenge.id)
  }

  const handleChallengeReset = async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge = await challengeService.updateUserChallenge(
      userChallenge,
      UserChallengeUpdateFlag.DUEL_RESET
    )
    dispatch(updateUserChallengeList(updatedChallenge))
  }

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(userChallenge.id + '-1', 'duelResult')
      setWinIcon(icon || defaultIcon)
      const icon2 = await importIconById(userChallenge.id + '-0', 'duelResult')
      setLossIcon(icon2 || defaultIcon)
    }
    handleEcogestureIcon()
  }, [userChallenge])

  return (
    <div className="cardContent cardDone">
      <div className="challengeName text-22-bold">
        {getChallengeTitleWithLineReturn(userChallenge.id)}
      </div>
      <div className="iconResult">
        <StyledIcon
          className="imgResult"
          icon={getIcon(userChallenge)}
          size={180}
        />
      </div>
      <div className="statsResult">
        <div
          className={classNames('labelResult', {
            win: userChallenge.success === UserChallengeSuccess.WIN,
            lost: userChallenge.success === UserChallengeSuccess.LOST,
          })}
        >
          {getResultLabel(userChallenge)}
        </div>
        <span className="text-18">
          {getUserSaving(userChallenge)}
          <span className="text-18-bold">
            {formatNumberValues(
              Math.abs(
                userChallenge.duel.threshold -
                  userChallenge.duel.userConsumption
              )
            ) + ' '}
            €
          </span>
          <br />
          {t('challenge.card_done.final_defi')}
        </span>
      </div>
      <div className="buttons">
        <Button
          aria-label={t('challenge.card_done.final_defi_view')}
          onClick={goDuel}
          className="btnSecondary"
        >
          {t('challenge.card_done.final_defi_view')}
        </Button>
        <Button
          aria-label={t('challenge.card_done.reset_defi')}
          onClick={handleChallengeReset}
          className={
            userChallenge.success === UserChallengeSuccess.WIN
              ? 'btnSecondary'
              : 'btnPrimaryNegative'
          }
          disabled={currentChallenge !== null}
        >
          {t('challenge.card_done.reset_defi')}
        </Button>
      </div>
    </div>
  )
}

export default ChallengeCardDone
