import Button from '@material-ui/core/Button'
import WaterBillIcon from 'assets/icons/visu/onboarding/water_bill.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidType } from 'enums'
import React from 'react'
import { setShowOfflineData } from 'store/chart/chart.slice'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import '../connection.scss'

const EpglBill = ({
  openModal: setOpenModal,
}: {
  openModal: (value: boolean) => void
}) => {
  const { t } = useI18n()
  const dispatch = useAppDispatch()
  const { fluidStatus } = useAppSelector(state => state.ecolyo.global)
  const currentFluidStatus = fluidStatus[FluidType.WATER]

  return (
    <div className="connection-form">
      <h2 className="connection-form-title eglgrandlyon text-20-bold">
        {t('auth.eglgrandlyon.no_account.title')}
      </h2>

      <StyledIcon icon={WaterBillIcon} size={180} />
      <p
        className="connection-form-subtitle text-16-regular"
        dangerouslySetInnerHTML={{ __html: t('auth.eglgrandlyon.bill') }}
      />

      <div className="connection-form-button">
        <Button
          aria-label={t('auth.eglgrandlyon.accessibility.connect')}
          onClick={() => setOpenModal(true)}
          className="btnPrimary"
        >
          {t('auth.eglgrandlyon.connect')}
        </Button>
        {currentFluidStatus.firstDataDate && (
          <Button
            className="btnSecondary"
            onClick={() => dispatch(setShowOfflineData(true))}
          >
            {t('auth.button_showOfflineData')}
          </Button>
        )}
      </div>
    </div>
  )
}

export default EpglBill
