import { render } from '@testing-library/react'
import { DataloadSectionType, DataloadState, FluidType } from 'enums'
import { Dataload } from 'models'
import React from 'react'
import { baseDataLoad } from 'tests/__mocks__/chartData.mock'
import DataloadSectionDetail from './DataloadSectionDetail'

describe('DataloadSectionDetail component', () => {
  it('should render correctly', () => {
    const { container } = render(
      <DataloadSectionDetail
        dataload={baseDataLoad}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.NO_COMPARE}
      />
    )
    expect(container).toMatchSnapshot()
  })
  it('should not display if multifluid and comparison', () => {
    const { container } = render(
      <DataloadSectionDetail
        dataload={baseDataLoad}
        fluidType={FluidType.MULTIFLUID}
        dataloadSectionType={DataloadSectionType.RIGHT}
      />
    )
    expect(container).toMatchSnapshot()
  })
  it('should not display value details if multifluid, no valueDetail and comparison', () => {
    const mockMultiDataload: Dataload = {
      ...baseDataLoad,
      state: DataloadState.AGGREGATED_EMPTY,
      valueDetail: null,
    }
    const { container } = render(
      <DataloadSectionDetail
        dataload={mockMultiDataload}
        fluidType={FluidType.MULTIFLUID}
        dataloadSectionType={DataloadSectionType.RIGHT}
      />
    )
    expect(container).toMatchSnapshot()
  })

  describe('should display value details if multifluid and no comparison', () => {
    it('case all valid data', () => {
      const mockMultiDataload: Dataload = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_VALID,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: 2, state: DataloadState.VALID },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const { container } = render(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(container).toMatchSnapshot()
    })
    it('case valid and coming data', () => {
      const mockMultiDataload: Dataload = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_WITH_COMING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.COMING },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const { container } = render(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(container).toMatchSnapshot()
    })
    it('case valid and missing data', () => {
      const mockMultiDataload: Dataload = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_WITH_HOLE_OR_MISSING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.MISSING },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const { container } = render(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(container).toMatchSnapshot()
    })
    it('case valid and hole data', () => {
      const mockMultiDataload: Dataload = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_WITH_HOLE_OR_MISSING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.HOLE },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const { container } = render(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(container).toMatchSnapshot()
    })
  })
})
