import { act, render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import EcogestureEmptyList from './EcogestureEmptyList'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockChangeTab = jest.fn()

describe('EcogestureEmptyList component', () => {
  it('should be rendered correctly', () => {
    const { container } = render(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={true}
        isSelectionDone={false}
        openResetEcogestureModal={jest.fn()}
      />
    )
    expect(container).toMatchSnapshot()
  })
  it('should return to all ecogestures', async () => {
    render(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={true}
        openResetEcogestureModal={jest.fn()}
      />
    )
    await act(async () => {
      await userEvent.click(screen.getByLabelText('ecogesture.emptyList.btn1'))
    })
    expect(mockChangeTab).toHaveBeenCalledTimes(1)
  })
  it('should launch ecogesture form', async () => {
    render(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={false}
        openResetEcogestureModal={jest.fn()}
      />
    )
    await act(async () => {
      await userEvent.click(screen.getByLabelText('ecogesture.emptyList.btn2'))
    })
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-form')
  })
  it('should render doing text with empty list on completed selection', () => {
    render(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={false}
        isSelectionDone={true}
        openResetEcogestureModal={jest.fn()}
      />
    )
    expect(
      screen.getByText('ecogesture.emptyList.doing1_done')
    ).toBeInTheDocument()
  })
  it('should render objective text with empty list on completed selection', () => {
    render(
      <EcogestureEmptyList
        setTab={mockChangeTab}
        isObjective={true}
        isSelectionDone={true}
        openResetEcogestureModal={jest.fn()}
      />
    )
    expect(
      screen.getByText('ecogesture.emptyList.obj1_done')
    ).toBeInTheDocument()
  })
})
