import { Button } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React from 'react'
import './ecogestureInitModal.scss'

interface EcogestureInitModalProps {
  open: boolean
  onClose: () => void
  onAccept: () => void
}

const EcogestureInitModal = ({
  open,
  onClose,
  onAccept,
}: EcogestureInitModalProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      onClose={onClose}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('feedback.accessibility.window_title')}
      </div>
      <StyledIconButton
        icon={CloseIcon}
        onClick={onClose}
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
      />
      <div className="eg-init-modal">
        <div className="title text-20-bold">
          {t('ecogesture.initModal.title')}
        </div>
        <div className="text-16-normal">{t('ecogesture.initModal.text1')}</div>
        <div className="text-16-normal">{t('ecogesture.initModal.text2')}</div>
        <div className="buttons-container">
          <Button onClick={onAccept} className="btnPrimary">
            {t('ecogesture.initModal.btn2')}
          </Button>
          <Button onClick={onClose} className="btnSecondary">
            {t('ecogesture.initModal.btn1')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default EcogestureInitModal
