import * as Sentry from '@sentry/react'
import { useClient } from 'cozy-client'
import get from 'lodash/get'
import { useEffect, useState } from 'react'

interface UserInstanceSettingsAttributes {
  auth_mode?: string
  auto_update?: boolean
  context?: string
  email?: string
  locale?: string
  oidc_id?: string
  onboarding_finished?: boolean
  public_name: string
  tos?: string
  tos_latest?: string
  uuid?: string
}

const useUserInstanceSettings = (): {
  instanceSettings: UserInstanceSettingsAttributes
} => {
  const client = useClient()
  const [settings, setSettings] = useState<UserInstanceSettingsAttributes>({
    // eslint-disable-next-line camelcase
    public_name: '',
  })

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await client
          .getStackClient()
          .fetchJSON('GET', '/settings/instance')
        setSettings(get(response, 'data.attributes'))
      } catch (error) {
        console.error(error)
        Sentry.captureException(error)
      }
    }
    fetchData()
  }, [client])

  return {
    instanceSettings: settings,
  }
}

export default useUserInstanceSettings
