import { act, render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import { FluidType, KonnectorError } from 'enums'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import KonnectorModal from './KonnectorModal'

const mockHandleCloseClick = jest.fn()

describe('KonnectorModal component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })
  it('should be rendered correctly', () => {
    const { baseElement } = render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state={null}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(baseElement).toMatchSnapshot()
  })
  it('should be with updating text', () => {
    const { baseElement } = render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state={null}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(
      baseElement.getElementsByClassName('kmodal-waiting-text')[0]
    ).toBeTruthy()
  })
  it('should be correctly closed', async () => {
    render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state="errored"
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    await act(async () => {
      await userEvent.click(screen.getByText('konnector_modal.button_validate'))
    })
    expect(mockHandleCloseClick).toHaveBeenCalled()
  })
  it('should render login error', async () => {
    const { baseElement } = render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state="error"
          error={KonnectorError.LOGIN_FAILED}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(
      baseElement.getElementsByClassName('headerError')[0]
    ).toBeInTheDocument()
  })
  it('should render unknown error', async () => {
    render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state="error"
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(screen.getByText('konnector_modal.error_data_2')).toBeInTheDocument()
  })
  it('should render update error', async () => {
    const { baseElement } = render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state={null}
          error={null}
          fluidType={FluidType.WATER}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(
      baseElement.getElementsByClassName('waiting-text')[0]
    ).toBeInTheDocument()
  })

  it('should render nothing if error is CHALLENGE_ASKED on Gas', () => {
    render(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          state={null}
          error={KonnectorError.CHALLENGE_ASKED}
          fluidType={FluidType.GAS}
          handleCloseClick={mockHandleCloseClick}
          isVerifyingIdentity={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(screen.queryByRole('dialog')).toBeNull()
  })
})
