import mockClient from 'tests/__mocks__/client.mock'
import {
  mockCustomPopup,
  mockCustomPopupWithLink,
} from 'tests/__mocks__/customPopup.mock'
import CustomPopupService from './customPopup.service'

jest.mock('services/environment.service', () => {
  return jest.fn(() => ({
    isProduction: () => true,
  }))
})

describe('PartnersInfo service', () => {
  const customPopupService = new CustomPopupService(mockClient)

  it('should return customPopup data', async () => {
    mockClient.getStackClient().fetchJSON.mockResolvedValueOnce(mockCustomPopup)
    const result = await customPopupService.getCustomPopup()
    expect(result).toBe(mockCustomPopup)
  })

  it('should return customPopup data with replaced link', async () => {
    mockClient
      .getStackClient()
      .fetchJSON.mockResolvedValueOnce(mockCustomPopupWithLink)
    const result = await customPopupService.getCustomPopup()
    expect(result).toStrictEqual({
      ...mockCustomPopupWithLink,
      description:
        '<p>Allez voir la page <a href="./#/ecogestures" target="_self">astuces</a> !!</p>',
    })
  })

  it('should return an error', async () => {
    mockClient.getStackClient().fetchJSON.mockRejectedValue(new Error())
    let res
    try {
      res = await customPopupService.getCustomPopup()
      expect(true).toBe(false)
    } catch (error) {
      //
    }
    expect(res).toBe(undefined)
  })
})
