import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'
import { Client } from 'cozy-client'
import { DateTime } from 'luxon'
import { Profile } from 'models'
import ProfileService from 'services/profile.service'
import { AppDispatch, AppState } from 'store/store'

const initialState: Profile = {
  id: '',
  ecogestureHash: '',
  challengeHash: '',
  duelHash: '',
  quizHash: '',
  explorationHash: '',
  isFirstConnection: false,
  partnersIssueSeenDate: {
    enedis: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
      zone: 'utc',
    }),
    egl: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
      zone: 'utc',
    }),
    grdf: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
      zone: 'utc',
    }),
  },
  lastConnectionDate: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  customPopupDate: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  haveSeenLastAnalysis: true,
  sendAnalysisNotification: true,
  sendConsumptionAlert: false,
  waterDailyConsumptionLimit: 0,
  mailToken: '',
  monthlyAnalysisDate: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
  isProfileTypeCompleted: false,
  isProfileEcogestureCompleted: false,
  onboarding: {
    isWelcomeSeen: true,
  },
  haveSeenEcogestureModal: false,
  activateHalfHourDate: DateTime.fromISO('0000-01-01T00:00:00.000Z', {
    zone: 'utc',
  }),
}

export const profileSlice = createSlice({
  name: 'profile',
  initialState,
  reducers: {},
  extraReducers: builder => {
    builder.addCase(updateProfile.fulfilled, (state, action) => {
      Object.assign(state, action.payload)
    })
  },
})

/**
 * Thunk updating profile in couch DB.
 * If the profile has an update, dispatch it to the app
 */
export const updateProfile = createAsyncThunk<
  Profile | void,
  Partial<Profile>,
  { dispatch: AppDispatch; state: AppState; extra: { client: Client } }
>('profile/updateProfile', async (profileUpdates, thunkAPI) => {
  const client = thunkAPI.extra.client
  const profileService = new ProfileService(client)
  const updatedProfile = await profileService.updateProfile(profileUpdates)
  if (updatedProfile) {
    return updatedProfile
  }
})
